JpegMarker class

A class representing a JPEG marker.

Constructors

JpegMarker(int type, int segmentLength, String? description)

Properties

contentLength → int
The content size of the marker. Could be negative if segment length is invalid.
no setter
description → String?
null means unknown marker.
final
hashCode → int
The hash code for this object.
no setterinherited
markerLength → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segmentLength → int
The segment size of the marker. -1 means unknown marker.
final
type → int
The type byte of the marker.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited